imblearn.ensemble.EasyEnsemble
==============================

.. currentmodule:: imblearn.ensemble

.. autoclass:: EasyEnsemble

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~EasyEnsemble.__init__
      ~EasyEnsemble.fit
      ~EasyEnsemble.fit_sample
      ~EasyEnsemble.get_params
      ~EasyEnsemble.sample
      ~EasyEnsemble.set_params
   
   

   
   
   